@@ -1,5 +1,5 @@
 package VM::JiffyBox::Box;
-$VM::JiffyBox::Box::VERSION = '0.031';
+$VM::JiffyBox::Box::VERSION = '0.032';
 # ABSTRACT: Representation of a Virtual Machine in JiffyBox
 
 use strict;
@@ -116,12 +116,20 @@ sub clone {
 sub _status_action {
     my $self   = shift;
     my $action = shift;
+    my $params = shift;
+
+    return if !$action;
 
     my $status = uc $action;
     $status    = 'SHUTDOWN' if 'stop' eq lc $action;
+
+    my %opts;
+    if ( $status eq 'THAW' ) {
+        $opts{planid} = $params->{planid};
+    }
     
     my $url  = $self->{hypervisor}->base_url . '/jiffyBoxes/' . $self->id;
-    my $json = to_json( { status => $status } );
+    my $json = to_json( { %opts, status => $status } );
     
     # POSSIBLE EXIT
     return { url => $url, json => $json }
@@ -154,7 +162,7 @@ sub freeze {
 sub thaw {
     my $self = shift;
 
-    return $self->_status_action( 'thaw' );
+    return $self->_status_action( 'thaw', shift );
 }
 
 sub start {
@@ -199,7 +207,7 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
@@ -207,7 +215,7 @@ VM::JiffyBox::Box - Representation of a Virtual Machine in JiffyBox
 
 =head1 VERSION
 
-version 0.031
+version 0.032
 
 =head1 SYNOPSIS
 
@@ -363,7 +371,9 @@ freeze a virtual machine.
 
 Thaw a virtual machine.
 
-  $box->thaw();
+  $box->thaw({
+      planid => 22,
+  });
 
 =head2 delete
 
@@ -392,7 +402,7 @@ Tim Schwarz, Boris Däppen <bdaeppen.perl@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Tim Schwarz, Boris Däppen, plusW.
+This software is copyright (c) 2016 by Tim Schwarz, Boris Däppen, plusW.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
